@@ -783,65 +783,6 @@ class DescribeRoomInformationResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
-class DescribeTrtcInteractiveTimeRequest(AbstractModel):
-    """DescribeTrtcInteractiveTime请求参数结构体
-
-    """
-
-    def __init__(self):
-        r"""
-        :param StartTime: 查询开始时间，格式为YYYY-MM-DD。
-        :type StartTime: str
-        :param EndTime: 查询结束时间，格式为YYYY-MM-DD。
-单次查询统计区间最多不能超过31天。
-        :type EndTime: str
-        :param SdkAppId: 应用ID，可不传。传应用ID时返回的是该应用的用量，不传时返回所有应用的合计值。
-        :type SdkAppId: int
-        """
-        self.StartTime = None
-        self.EndTime = None
-        self.SdkAppId = None
-
-
-    def _deserialize(self, params):
-        self.StartTime = params.get("StartTime")
-        self.EndTime = params.get("EndTime")
-        self.SdkAppId = params.get("SdkAppId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
-        
-
-
-class DescribeTrtcInteractiveTimeResponse(AbstractModel):
-    """DescribeTrtcInteractiveTime返回参数结构体
-
-    """
-
-    def __init__(self):
-        r"""
-        :param Usages: 应用的用量信息数组。
-        :type Usages: list of OneSdkAppIdUsagesInfo
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
-        self.Usages = None
-        self.RequestId = None
-
-
-    def _deserialize(self, params):
-        if params.get("Usages") is not None:
-            self.Usages = []
-            for item in params.get("Usages"):
-                obj = OneSdkAppIdUsagesInfo()
-                obj._deserialize(item)
-                self.Usages.append(obj)
-        self.RequestId = params.get("RequestId")
-
-
 class DescribeTrtcMcuTranscodeTimeRequest(AbstractModel):
     """DescribeTrtcMcuTranscodeTime请求参数结构体
 
@@ -1106,7 +1047,7 @@ class EncodeParams(AbstractModel):
         :type BackgroundImageId: int
         :param AudioCodec: 混流-输出流音频编码类型，取值范围[0,1, 2]，0为LC-AAC，1为HE-AAC，2为HE-AACv2。默认值为0。当音频编码设置为HE-AACv2时，只支持输出流音频声道数为双声道。HE-AAC和HE-AACv2支持的输出流音频采样率范围为[48000, 44100, 32000, 24000, 16000]
         :type AudioCodec: int
-        :param BackgroundImageUrl: 混流-输出流背景图片URL地址，支持png、jpg、jpeg、bmp格式，暂不支持透明通道。URL链接长度限制为512字节。BackgroundImageUrl和BackgroundImageId参数都填时，以BackgroundImageUrl为准。图片大小限制不超过10MB。
+        :param BackgroundImageUrl: 混流-输出流背景图片URL地址，支持png、jpg、jpeg、bmp格式，暂不支持透明通道。URL链接长度限制为512字节。BackgroundImageUrl和BackgroundImageId参数都填时，以BackgroundImageUrl为准。图片大小限制不超过2MB。
         :type BackgroundImageUrl: str
         """
         self.AudioSampleRate = None
@@ -1389,43 +1330,6 @@ class OneSdkAppIdTranscodeTimeUsagesInfo(AbstractModel):
         
 
 
-class OneSdkAppIdUsagesInfo(AbstractModel):
-    """单个SdkAppId的音视频互动计费时长用量数组和数组长度。
-
-    """
-
-    def __init__(self):
-        r"""
-        :param TotalNum: 该 SdkAppId 对应的用量记录数长度
-        :type TotalNum: int
-        :param SdkAppIdTrtcTimeUsages: 用量数组
-        :type SdkAppIdTrtcTimeUsages: list of SdkAppIdTrtcUsage
-        :param SdkAppId: 应用ID
-        :type SdkAppId: str
-        """
-        self.TotalNum = None
-        self.SdkAppIdTrtcTimeUsages = None
-        self.SdkAppId = None
-
-
-    def _deserialize(self, params):
-        self.TotalNum = params.get("TotalNum")
-        if params.get("SdkAppIdTrtcTimeUsages") is not None:
-            self.SdkAppIdTrtcTimeUsages = []
-            for item in params.get("SdkAppIdTrtcTimeUsages"):
-                obj = SdkAppIdTrtcUsage()
-                obj._deserialize(item)
-                self.SdkAppIdTrtcTimeUsages.append(obj)
-        self.SdkAppId = params.get("SdkAppId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
-        
-
-
 class OutputParams(AbstractModel):
     """MCU混流的输出参数
 
@@ -1931,52 +1835,6 @@ class SdkAppIdTrtcMcuTranscodeTimeUsage(AbstractModel):
         
 
 
-class SdkAppIdTrtcUsage(AbstractModel):
-    """查询音视频互动时长的输出数据。
-    查询时间小于等于1天时，返回每5分钟粒度的数据；查询时间大于1天时，返回按天汇总的数据。
-
-    """
-
-    def __init__(self):
-        r"""
-        :param TimeKey: 本组数据对应的时间点，格式如：2020-09-07或2020-09-07 00:05:05。
-        :type TimeKey: str
-        :param AudioTime: 语音时长，单位：秒。
-        :type AudioTime: int
-        :param AudioVideoTime: 音视频时长，单位：秒。
-2019年10月11日前注册，没有变更为 [新计费模式](https://cloud.tencent.com/document/product/647/17157) 的用户才会返回此值。
-        :type AudioVideoTime: int
-        :param VideoTimeSd: 视频时长-标清SD，单位：秒。
-        :type VideoTimeSd: int
-        :param VideoTimeHd: 视频时长-高清HD，单位：秒。
-        :type VideoTimeHd: int
-        :param VideoTimeHdp: 视频时长-超清HD，单位：秒。
-        :type VideoTimeHdp: int
-        """
-        self.TimeKey = None
-        self.AudioTime = None
-        self.AudioVideoTime = None
-        self.VideoTimeSd = None
-        self.VideoTimeHd = None
-        self.VideoTimeHdp = None
-
-
-    def _deserialize(self, params):
-        self.TimeKey = params.get("TimeKey")
-        self.AudioTime = params.get("AudioTime")
-        self.AudioVideoTime = params.get("AudioVideoTime")
-        self.VideoTimeSd = params.get("VideoTimeSd")
-        self.VideoTimeHd = params.get("VideoTimeHd")
-        self.VideoTimeHdp = params.get("VideoTimeHdp")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
-        
-
-
 class SmallVideoLayoutParams(AbstractModel):
     """画中画模板中有效，代表小画面的布局参数
 
@@ -2346,7 +2204,7 @@ class WaterMarkParams(AbstractModel):
         :type LocationX: int
         :param LocationY: 水印在输出时的Y偏移。单位为像素值。
         :type LocationY: int
-        :param WaterMarkUrl: 混流-水印图片URL地址，支持png、jpg、jpeg、bmp格式，暂不支持透明通道。URL链接长度限制为512字节。WaterMarkUrl和WaterMarkId参数都填时，以WaterMarkUrl为准。图片大小限制不超过10MB。
+        :param WaterMarkUrl: 混流-水印图片URL地址，支持png、jpg、jpeg、bmp格式，暂不支持透明通道。URL链接长度限制为512字节。WaterMarkUrl和WaterMarkId参数都填时，以WaterMarkUrl为准。图片大小限制不超过2MB。
         :type WaterMarkUrl: str
         """
         self.WaterMarkId = None
